@@ -17,8 +17,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
-
 import collections
 from collections.abc import Sequence
 import copy
@@ -1362,8 +1360,7 @@ def port_get(request, port_id, **params):
 
 
 def unescape_port_kwargs(**kwargs):
-    keys = list(kwargs)
-    for key in keys:
+    for key in kwargs:
         if '__' in key:
             kwargs[':'.join(key.split('__'))] = kwargs.pop(key)
     return kwargs
